@@ -1,4 +1,4 @@
-# Copyrights 1998,2005-2009 by Mark Overmeer.
+# Copyrights 1998,2005-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 1.06.
@@ -7,7 +7,7 @@ use strict;
 
 package CPAN::Site::Index;
 use vars '$VERSION';
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 use base 'Exporter';
 
@@ -61,6 +61,11 @@ sub cpan_index($@)
     my $fallback = $opts{fallback};
     my $undefs   = exists $opts{undefs} ? $opts{undefs} : 1;
 
+    unless($ua)
+    {   $ua = LWP::UserAgent->new;
+        $ua->env_proxy if $opts{env_proxy};
+    }
+
     -d $mycpan
         or error __x"archive top '{dir}' is not a directory"
              , dir => $mycpan;
@@ -273,7 +278,6 @@ sub update_global_cpan($$)
 
 sub load_file($$)
 {   my ($from, $to) = @_;
-    $ua ||= LWP::UserAgent->new;
     my $response = $ua->get($from, ':content_file' => $to);
     return if $response->is_success;
 
@@ -415,6 +419,11 @@ sub cpan_mirror($$$@)
     my %need = map { ($_ => 1) } @$mods;
     my $auth = catdir $mycpan, 'authors', 'id';
 
+    unless($ua)
+    {   $ua = LWP::UserAgent->new;
+        $ua->env_proxy if $opts{env_proxy};
+    }
+
     my $globdetails
              = update_global_cpan $mycpan, $globalcpan;
 
